@@ -6,7 +6,7 @@ from cartfreakapi import CartFreakError
 
 
 REQUIRED_VARS = ('command', 'hash')
-VALID_COMMANDS = ('CREATE', 'REMOVE', 'RENEW', 'COMPLETE')
+VALID_COMMANDS = ('CREATE', 'REMOVE', 'RENEW', 'COMPLETE', 'DECLINE')
 ERROR_STR = 'ERROR %s'
 
 
@@ -15,6 +15,9 @@ def handle_api(request, callback=None, key_name='CARTFREAKAPI_KEY'):
         raise ImproperlyConfigured(
             u'No CartFreak API setting configured for %s' % key_name
         )
+
+    if request.method != 'POST':
+        return HttpResponse(ERROR_STR % 'request must be sent as POST')
     
     cf_key = getattr(settings, key_name)
     for req in REQUIRED_VARS:
@@ -38,4 +41,4 @@ def handle_api(request, callback=None, key_name='CARTFREAKAPI_KEY'):
         except CartFreakError, err:
             return HttpResponse(ERROR_STR % str(err))
 
-    return HttpResponse('OK')
\ No newline at end of file
+    return HttpResponse('OK')
